from setuptools import setup

setup(
    name='upr',
    version='0.1',
    description='Basic UPR client',
    author='Pavel Paulau',
    author_email='pavel.paulau@gmail.com',
    py_modules=['upr'],
    classifiers=[
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
